@@ -1,4 +1,5 @@
 from argparse import ArgumentParser
+from sys import version_info
 
 _NO_FUNC = object()
 
@@ -6,6 +7,12 @@ _NO_FUNC = object()
 __all__ = ['App']
 
 
+if version_info[0] >= 32:
+    text_type = basestring
+else:
+    text_type = str
+
+
 class App(object):
     """
     Simple command line application.
@@ -35,12 +42,17 @@ class App(object):
         """
         return self._parser.set_defaults(**kwargs)
 
-    def cmd(self, _func=_NO_FUNC, name=None, *args, **kwargs):
-        """Decorator to create a command line subcommand for a function.
+    def cmd(self, _func=_NO_FUNC, name=None, alias=None, *args, **kwargs):
+        """
+        Decorator to create a command line subcommand for a function.
 
         By default, the name of the decorated function is used as the
-        name of the subcommand, but this can be overridden by specifying the
-        `name` argument. Additional arguments are passed to the subcommand's
+        name of the subcommand, but this can be overridden by specifying
+        the `name` argument. Aliases are also possible via the alias
+        argument, which takes either a string or a tuple/list of
+        strings.
+
+        Additional arguments are passed to the subcommand's
         :py:class:`ArgumentParser`.
         """
         if _func is not _NO_FUNC:
@@ -59,6 +71,21 @@ class App(object):
             subparser = self._subparsers.add_parser(
                 subcommand, *parser_args, **parser_kwargs)
 
+            # Register aliases, if specified
+            if alias:
+                # Accept both a tuple/list or a single string
+                if isinstance(alias, text_type):
+                    aliases = [alias]
+                else:
+                    aliases = alias
+
+                assert isinstance(aliases, (tuple, list))
+
+                # XXX: poking inside argparse internals is a ugly
+                parser_map = self._subparsers._name_parser_map
+                for subcommand_alias in aliases:
+                    parser_map[subcommand_alias] = parser_map[subcommand]
+
             # Add any pending arguments
             for args, kwargs in self._pending_args:
                 subparser.add_argument(*args, **kwargs)
